"use strict";

var isImplemented = require("../../../number/is-safe-integer/is-implemented");

module.exports = function (a) { a(isImplemented(), true); };
